@@ -8,6 +8,7 @@ adds some more which are easier to define here.
 -}
 
 module Hledger.Cli (
+                     module Hledger.Cli.Accounts,
                      module Hledger.Cli.Add,
                      module Hledger.Cli.Balance,
                      module Hledger.Cli.Balancesheet,
@@ -20,13 +21,17 @@ module Hledger.Cli (
                      module Hledger.Cli.Options,
                      module Hledger.Cli.Utils,
                      module Hledger.Cli.Version,
-                     tests_Hledger_Cli
+                     tests_Hledger_Cli,
+                     module Hledger,
+                     module System.Console.CmdArgs.Explicit
               )
 where
 import Data.Time.Calendar
+import System.Console.CmdArgs.Explicit
 import Test.HUnit
 
 import Hledger
+import Hledger.Cli.Accounts
 import Hledger.Cli.Add
 import Hledger.Cli.Balance
 import Hledger.Cli.Balancesheet
